import pickle
import configparser


# VOCABULARY OF THE MODEL
def get_VOCAB_model():
    # with open(vocabs_pkl_filepath, "rb") as f:
    #     vocab_model = pickle.load(f)
    
    file = 'config.ini'
    config = configparser.ConfigParser()
    config.read(file)

    # vocabs_pkl_filepath = config['PATHS']['vocabs_pkl_filepath']
    vocabs_pkl_filepath = config.get('PATHS', 'vocabs_pkl_filepath')

    with open(vocabs_pkl_filepath, "rb") as f:
        vocab_model = pickle.load(f)
    
    return vocab_model

get_VOCAB_model()


pos_h5_filepath = 'models/POS_TAG_WORD(1).h5'
postags_pkl_filepath = 'models/tagindex_model.pkl'
postagsindex_pkl_filepath = 'models/tagindex_model.pkl'
vocabs_pkl_filepath = 'models/vocab_model2.pkl'
corpus_csv_filepath = 'Datasets/annotatedtestxt.csv'